import useConfigChatStore from "@/feature/messenger/store/chat_store/useConfigChatStore";
import useConversationsStore from "@/feature/messenger/store/chat_store/useConversationsStore";
import useMessagesStore from "@/feature/messenger/store/chat_store/useMessagesStore";
import { createMessageFile } from "@/feature/messenger/services/chat/ChatService";

const SendFile = () => {
    const id_chatbot = useConfigChatStore(state => state.idChatbot);
    const selectedConversation = useConversationsStore(state => state.selectedConversation);
    const addItemListMessages = useMessagesStore(state => state.actions.addItemListMessages);
    const updateConversation = useConversationsStore(state => state.actions.updateConversation);

    const handleFile = async (file) => {
        if (!file) return;
        
        try {
            const res = await createMessageFile(id_chatbot, selectedConversation.sesion, file);
            const response = res.data;
            
            response.forEach(message => {
                addItemListMessages(message);
                updateConversation({
                    ...selectedConversation,
                    conversacion: message.conversacion,
                    tipomensaje: message.tipomensaje,
                    fecha: message.fecha_sistema
                });
            });
        } catch (error) {
            console.error("Error al enviar archivo:", error);
        }
    };

    return (
        <div 
            onClick={(e) => {
                e.preventDefault();
                e.stopPropagation();
                
                // Crear y activar input file directamente en el click
                const input = document.createElement('input');
                input.type = 'file';
                input.accept = '*/*'; // Acepta cualquier tipo de archivo
                input.onchange = (e) => {
                    const file = e.target.files?.[0];
                    if (file) handleFile(file);
                };
                input.click();
            }}
            className="flex items-center cursor-pointer px-0 py-0 hover:bg-transparent rounded"
        >
            Archivo
        </div>
    );
};

export default SendFile;